==> packageinstaller-pkglist_0.3.30.tar.xz: packageinstaller-pkglist/Punjabi_Firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Punjabi_Firefox
</name>

<description>
   <am>Punjabi localisation of Firefox</am>
   <ar>Punjabi localisation of Firefox</ar>
   <be>Punjabi localisation of Firefox</be>
   <bg>Punjabi localisation of Firefox</bg>
   <bn>Punjabi localisation of Firefox</bn>
   <ca>Punjabi localisation of Firefox</ca>
   <cs>Punjabi localisation of Firefox</cs>
   <da>Punjabi localisation of Firefox</da>
   <de>Punjabi localisation of Firefox</de>
   <el>Εντοπισμός του Firefox στα Παντζάμπι</el>
   <en>Punjabi localisation of Firefox</en>
   <es_ES>Punjabi localisation of Firefox</es_ES>
   <es>Localización Punjabi de Firefox</es>
   <et>Punjabi localisation of Firefox</et>
   <eu>Punjabi localisation of Firefox</eu>
   <fa>Punjabi localisation of Firefox</fa>
   <fil_PH>Punjabi localisation of Firefox</fil_PH>
   <fi>Punjabi localisation of Firefox</fi>
   <fr_BE>Punjabi localisation of Firefox</fr_BE>
   <fr>Punjabi localisation of Firefox</fr>
   <gl_ES>Punjabi localisation of Firefox</gl_ES>
   <he_IL>Punjabi localisation of Firefox</he_IL>
   <hi>Punjabi localisation of Firefox</hi>
   <hr>Punjabi localisation of Firefox</hr>
   <hu>Punjabi localisation of Firefox</hu>
   <id>Punjabi localisation of Firefox</id>
   <is>Punjabi localisation of Firefox</is>
   <it>Punjabi localisation of Firefox</it>
   <ja>Punjabi localisation of Firefox</ja>
   <kk>Punjabi localisation of Firefox</kk>
   <ko>Punjabi localisation of Firefox</ko>
   <lt>Punjabi localisation of Firefox</lt>
   <mk>Punjabi localisation of Firefox</mk>
   <mr>Punjabi localisation of Firefox</mr>
   <nb_NO>Punjabi localisation of Firefox</nb_NO>
   <nb>Punjabi localisation of Firefox</nb>
   <nl_BE>Punjabi localisation of Firefox</nl_BE>
   <nl>Punjabi localisation of Firefox</nl>
   <pl>Punjabi localisation of Firefox</pl>
   <pt_BR>Punjabi localisation of Firefox</pt_BR>
   <pt>Punjabi localisation of Firefox</pt>
   <ro>Punjabi localisation of Firefox</ro>
   <ru>Punjabi localisation of Firefox</ru>
   <sk>Punjabi localisation of Firefox</sk>
   <sl>Punjabi localisation of Firefox</sl>
   <sq>Punjabi localisation of Firefox</sq>
   <sr>Punjabi localisation of Firefox</sr>
   <sv>Punjabi localisation of Firefox</sv>
   <th>Punjabi localisation of Firefox</th>
   <tr>Punjabi localisation of Firefox</tr>
   <uk>Punjabi localisation of Firefox</uk>
   <vi>Punjabi localisation of Firefox</vi>
   <zh_CN>Punjabi localisation of Firefox</zh_CN>
   <zh_HK>Punjabi localisation of Firefox</zh_HK>
   <zh_TW>Punjabi localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-l10n-pa-in
</install_package_names>

<postinstall>
</postinstall>

<uninstall_package_names>
firefox-l10n-pa-in
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Punjabi_Firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Punjabi_Firefox
</name>

<description>
   <am>Punjabi localisation of Firefox</am>
   <ar>Punjabi localisation of Firefox</ar>
   <be>Punjabi localisation of Firefox</be>
   <bg>Punjabi localisation of Firefox</bg>
   <bn>Punjabi localisation of Firefox</bn>
   <ca>Punjabi localisation of Firefox</ca>
   <cs>Punjabi localisation of Firefox</cs>
   <da>Punjabi localisation of Firefox</da>
   <de>Pakistanische und Indische Lokalisation für die Sprache “Pandschabisch” von “Firefox”</de>
   <el>Εντοπισμός του Firefox στα Παντζάμπι</el>
   <en>Punjabi localisation of Firefox</en>
   <es_ES>Localización Punjabi de Firefox</es_ES>
   <es>Localización Punjabi de Firefox</es>
   <et>Punjabi localisation of Firefox</et>
   <eu>Punjabi localisation of Firefox</eu>
   <fa>Punjabi localisation of Firefox</fa>
   <fil_PH>Punjabi localisation of Firefox</fil_PH>
   <fi>Punjabi localisation of Firefox</fi>
   <fr_BE>Punjabi localisation of Firefox</fr_BE>
   <fr>Localisation en pendjabi (Inde) pour Firefox</fr>
   <gl_ES>Punjabi localisation of Firefox</gl_ES>
   <gu>Punjabi localisation of Firefox</gu>
   <he_IL>Punjabi localisation of Firefox</he_IL>
   <hi>Punjabi localisation of Firefox</hi>
   <hr>Punjabi localisation of Firefox</hr>
   <hu>Punjabi localisation of Firefox</hu>
   <id>Punjabi localisation of Firefox</id>
   <is>Punjabi localisation of Firefox</is>
   <it>Localizzazione punjabi di Firefox</it>
   <ja>パンジャーブ語版 Firefox</ja>
   <kk>Punjabi localisation of Firefox</kk>
   <ko>Punjabi localisation of Firefox</ko>
   <lt>Punjabi localisation of Firefox</lt>
   <mk>Punjabi localisation of Firefox</mk>
   <mr>Punjabi localisation of Firefox</mr>
   <nb_NO>Punjabi localisation of Firefox</nb_NO>
   <nb>Punjabi lokaltilpassing av Firefox</nb>
   <nl_BE>Punjabi localisation of Firefox</nl_BE>
   <nl>Punjabi localisation of Firefox</nl>
   <pl>Punjabi localisation of Firefox</pl>
   <pt_BR>Punjabi Localização para o Firefox</pt_BR>
   <pt>Punjabi localisation of Firefox</pt>
   <ro>Punjabi localisation of Firefox</ro>
   <ru>Punjabi localisation of Firefox</ru>
   <sk>Punjabi localisation of Firefox</sk>
   <sl>Punjabi localisation of Firefox</sl>
   <sq>Punjabi localisation of Firefox</sq>
   <sr>Punjabi localisation of Firefox</sr>
   <sv>Punjabi lokalisering för Firefox</sv>
   <th>Punjabi localisation of Firefox</th>
   <tr>Punjabi localisation of Firefox</tr>
   <uk>Punjabi localisation of Firefox</uk>
   <vi>Punjabi localisation of Firefox</vi>
   <zh_CN>Punjabi localisation of Firefox</zh_CN>
   <zh_HK>Punjabi localisation of Firefox</zh_HK>
   <zh_TW>Punjabi localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-l10n-pa-in
</install_package_names>

<postinstall>
</postinstall>

<uninstall_package_names>
firefox-l10n-pa-in
</uninstall_package_names>

</app>
